@@ -1,9 +1,9 @@
 <?php
 include_once(dirname(__FILE__).'/includes/utils.inc.php');
 
-$this_version = '4.5.9';
-$this_year = '2024';
-$theme = $cfg['theme'] ?? 'dark';
+$this_version = '4.5.11';
+$this_year = '2026';
+$theme = isset($cfg['theme']) ? $cfg['theme'] : 'dark';
 if ($theme != 'dark' && $theme != 'light') {
 	$theme = 'dark';
 }
@@ -72,7 +72,7 @@ if ($theme != 'dark' && $theme != 'light') {
 <div id="currentversioninfo">
 	<div>
 		<div class="version">Version <b><?php echo $this_version; ?></b></div>
-		<div class="releasedate">December 19, 2024</div>
+		<div class="releasedate">January 14, 2026</div>
 	</div>
 	<div><span id="core-status"></span></div>
 	<a class="checkforupdates" href="https://www.nagios.org/checkforupdates/?version=<?php echo $this_version; ?>&amp;product=nagioscore" target="_blank">Check for updates</a>
@@ -101,12 +101,12 @@ if ($theme != 'dark' && $theme != 'light') {
 </div>
 
 <div id="mainsplash">
-	<a href="https://www.nagios.org/launch?utm_campaign=csp&utm_source=nagioscore&utm_medium=splash_thumbnail&utm_content=<?php echo $this_version; ?>" target="_blank"><img src="images/csp-dashboard.avif" /></a>
+	<a href="https://www.nagios.org/?utm_campaign=csp&utm_source=nagioscore&utm_medium=splash_thumbnail&utm_content=<?php echo $this_version; ?>" target="_blank"><img src="images/csp-dashboard.avif" /></a>
 	<div id="splashtext">
 		<div id="splashtexttitle">Meet Nagios Core Services Platform</div>
 		<div>The next generation of Open Source powered monitoring with advanced dashboards, monitoring wizards, and much more!</div>
 		<div id="splashbuttons">
-			<a id="splashlearnmore" href="https://www.nagios.org/launch?utm_campaign=csp&utm_source=nagioscore&utm_medium=splash_button&utm_content=<?php echo $this_version; ?>" target="_blank">Learn More</a>
+			<a id="splashlearnmore" href="https://www.nagios.org/?utm_campaign=csp&utm_source=nagioscore&utm_medium=splash_button&utm_content=<?php echo $this_version; ?>#csp-section-home" target="_blank">Learn More</a>
 			<a id="splashnewsletter" href="https://www.nagios.org/newsletter?utm_campaign=csp&utm_source=nagioscore&utm_medium=splash_newsletter_link&utm_content=<?php echo $this_version; ?>" target="_blank">Newsletter Sign-Up</a>
 		</div>
 	</div>
